<?php
namespace Transcy\Admin;
use Transcy\Admin\Options;
use Transcy\Base\Crisp;
use Transcy\Helpers\Info;
use Transcy\Api\AppApi\AppToken;

class Dashboard {
    public function register() {
        add_action('admin_menu', array($this, 'add_menu'));
        add_filter('admin_footer_text', '__return_false');
        add_action('init', array($this, 'add_cors_http_header'));
        add_action('init', array($this, 'add_ctp_language'));
        add_filter('init', array($this, 'generate_apikey'));
        add_filter('in_admin_header', array($this, 'hide_all_notice'), 99);
    }

    /**
     * Add menu in dashboard
     */
    public function add_menu() {
        add_menu_page(
            'Transcy dashboard', 
            'Transcy',
            'manage_options',
            'transcy-dashboard',
            array($this, 'render_html'),
            TRANSCY_ASSETS_FOLDER.'/images/icon.svg',
            2
        );
        add_submenu_page(
            'transcy-dashboard',
            'Language',
            'Language',
            'manage_options',
            'admin.php?page=transcy-dashboard#/language'
        );
        add_submenu_page(
            'transcy-dashboard',
            'Currency',
            'Currency',
            'manage_options',
            'admin.php?page=transcy-dashboard#/currency'
        );
        add_submenu_page(
            'transcy-dashboard',
            'Switcher',
            'Switcher',
            'manage_options',
            'admin.php?page=transcy-dashboard#/switcher'
        );
        // add_submenu_page(
        //     'transcy-dashboard',
        //     'Upgrade version',
        //     'Upgrade version',
        //     'manage_options',
        //     'admin.php?page=transcy-dashboard#/upgrade'
        // );
        // add_submenu_page(
        //     'transcy-dashboard',
        //     'Button demo',
        //     'Button demo',
        //     'manage_options',
        //     'button-demo',
        //     array($this, 'button_demo_html')
        // );
    }

    /**
     * Render to view
     */
    public function render_html() {
        $crisp = new Crisp();
        $data_crisp = $crisp->get_data();

        require_once(TRANSCY_TEMPLATES_ADMIN . "/dashboard.php");
    }

    public function button_demo_html() {
        $info = new Info();
        $app_token = new AppToken();
        $domain = $info->get_domain();
        $token = $app_token->generate_token();
        $link = APP_URL."/auth/login?domain=$domain&app_version=1.0.0&access_token=$token";
        
        require_once(TRANSCY_TEMPLATES_ADMIN . "/button-demo.php");
    }

    /**
     * Fix cros api
     */
    public function add_cors_http_header() {
        header("Access-Control-Allow-Origin: *");
        // header("Access-Control-Allow-Credentials: true");
        // header("Access-Control-Allow-Methods: GET,HEAD,OPTIONS,POST,PUT");
        header("Access-Control-Allow-Headers: Origin, X-Requested-With, X-WP-Nonce, Content-Type, Accept, Authorization");
    }

    /**
    * Add custom post language
    */
    public function add_ctp_language() {
        register_post_type('transcy-lang',
            array(
                'labels' => array(
                    'name' => __( 'Languages' ),
                    'singular_name' => __( 'Language' )
                ),
                'public' => true,
                'has_archive' => false,
                "show_in_menu" => false,
                'rewrite' => array('slug' => 'transcy-lang'),
                'show_in_rest' => true,
                'supports' => array('title', 'custom-fields')
            )
        );
    }

    /**
    * Generate key
    **/
    public function generate_apikey() {
        $option = new Options();

        if(!$option->check_option_already('transcy_apikey')) {
            $option->set_option('transcy_apikey', md5(strtotime("now")));
        }
    }

    /**
    * Hide all notice
    **/
    public function hide_all_notice() {
        global $pagenow;

        if($pagenow == 'admin.php'
            && (
                $_GET['page'] == 'transcy-dashboard'
                || $_GET['page'] == 'button-demo'
            )
        ) {
            remove_all_actions( 'user_admin_notices' );
            remove_all_actions( 'admin_notices' );  
        }       
    }

}
