<?php

namespace Transcy\Admin;

use Transcy\Model\Notification as m_noti;
use Transcy\Base\Curl;
use Transcy\Api\AppApi\AppToken;

class Notification
{
    public function register()
    {
        global $pagenow;
        if (is_admin() && $pagenow == 'index.php') {
            add_action('admin_init', array($this, 'create_table'));
            add_action('admin_init', array($this, 'update_data'));
        }

        add_action('admin_notices', array($this, 'show_notify'), 0);
    }

    public function create_table()
    {
        $model = new m_noti();
        $model->create_table();
    }

    public function update_data()
    {
        $curl = new Curl();
        $model = new m_noti();
        $app_token = new AppToken();
        $token = $app_token->generate_token();
        $header = array(
            "Authorization: Bearer $token",
        );
        $data = $curl->call_api(APP_API_URL . '/api/notifications', 'GET', '', $header);
        $data = !empty($data['data']['items']) ? json_decode($data, true)['data']['items'] : null;

        if (!empty($data)) {
            foreach ($data as $row) {
                if ($model->check_has_data($row['id']) == 1) {
                    $model->update_record(
                        $row['id'],
                        $row['message'],
                        $row['type'],
                        $row['order']
                    );
                } else {
                    $model->add_record(
                        $row['id'],
                        $row['message'],
                        $row['status'],
                        $row['type'],
                        $row['order']
                    );
                }
            }
        }

        $this->remove_record_not_exist($data);
    }

    public function remove_record_not_exist($data_server)
    {
        $model = new m_noti();
        $ids_data_server = [];
        if (!empty($data_server)) {
            foreach ($data_server as $data) {
                $ids_data_server[] = $data['id'];
            }
        }

        $list_notiy = $model->get_all_data();
        if (!empty($list_notiy)) {
            foreach ($list_notiy as $noti) {
                if (!in_array($noti->id, $ids_data_server)) {
                    $model->delete_record($noti->id);
                }
            }
        }
    }

    public function check_links($html)
    {
        $doc = new \DOMDocument;
        $doc->loadHTML($html);

        foreach ($doc->getElementsByTagName('a') as $element) {
            if ($element->textContent == 'Update now') {
                $element->setAttribute('href', get_admin_url() . 'plugins.php');
            }
        }

        return $doc->saveHTML();
    }

    public function show_notify()
    {
        $doc = new \DOMDocument;
        $model = new m_noti();
        $data = $model->get_data();
        $class = 'update-nag notice inline transcy-notify';
        $logo = TRANSCY_ASSETS_FOLDER . '/images/logo.svg';
        $btn_close = 'dashicons dashicons-dismiss';
        $id_notify = 1;

        if (!empty($data)) {
            foreach ($data as $row) {
                printf('<div class="%1$s notice-%2$s">
							<div class="inner">
								<div class="tc-logo">
									<img src="%3$s" alt="" />
								</div>
								<div class="msg">
								%4$s
								</div>
								<div class="btn-close" data-id="%5$s">
									<span class="%6$s"></span>
								</div>
							</div>
					   	</div>',
                    esc_attr($class),
                    esc_attr($row->type),
                    esc_html($logo),
                    $this->check_links($row->message),
                    esc_attr($row->id),
                    esc_attr($btn_close)
                );
            }
        }
    }

}
