<?php

namespace Transcy\Admin;

use Transcy\Api\AppApi\ClientApi;
use Transcy\Model\RelationshipLanguage;

class WPAdmin
{
    public function register()
    {
        add_filter('pre_get_posts', array($this, 'translate_post_query'));
        add_filter('terms_clauses', array($this, 'terms_clauses_tc_taxonomy_to_WPQuery'), 10, 3);

        // woo hook price
        add_filter('woocommerce_product_get_price', [$this, 'tc_change_product_price_convert'], 10, 1);
        add_filter('woocommerce_product_get_regular_price', [$this, 'tc_change_product_price_convert'], 10, 1);
        add_filter('woocommerce_product_get_sale_price', [$this, 'tc_change_product_price_convert'], 10, 1);

        add_filter('woocommerce_currency_symbol', [$this, 'tc_change_product_price_display'], 10, 2);

        add_filter('init', array($this, 'created_translation_relationships_table'));
    }

    public function created_translation_relationships_table()
    {
        $translation_relationships = new RelationshipLanguage();
        $translation_relationships->creating_transcy_relationship_tables();
    }

    public function translate_post_query(\WP_Query $query)
    {

        //Is admin page
        if (is_admin()) {
            $query->set('suppress_filters', false);
            add_filter('posts_clauses', array($this, 'posts_clauses_hide_tc_post'), 20, 1);
            return;
        }

        //Is front page
        if (!is_admin() && !$query->is_singular()) {
            $lang = !empty($_GET['lang']) ? $_GET['lang'] : null;

            $client_api = new ClientApi();
            $client_data = $client_api->get_client_data();
            if (!empty($client_data)) {
                $client_data = $client_data->data;
                $lang_info = array_filter($client_data->languages, function ($var) use ($lang) {
                    return ($var->code == $lang);
                });
                $lang_info = array_shift($lang_info);
                $lang_default = $client_data->default_language;
                if (is_null($lang) || $lang == $lang_default->code || $lang_info->type === 1) {
                    add_filter('posts_clauses', array($this, 'posts_clauses_hide_tc_post'), 20, 1);
                } else {
                    add_filter('posts_join', array($this, 'join_tc_post_to_WPQuery'));
                }
            }
        }
    }

    public function tc_change_product_price_convert($price)
    {
        if (!is_admin() && !empty($_GET['currency'])) {
            $currency_get = $_GET['currency'];
            $client_api = new ClientApi();
            $client_data = $client_api->get_client_data();
            if (!empty($client_data)) {
                $client_data = $client_data->data;
                $currency_default = $client_data->currencies[0];
                $currency_active = array_filter($client_data->currencies, function ($var) use ($currency_get) {
                    return ($var->code == $currency_get);
                });
                $currency_active = !empty($currency_active) ? array_shift($currency_active) : null;
                if ($currency_active->code != $currency_default->code) {
                    if ($currency_default->code == "USD") {
                        $exchange_rate = $currency_active->settings->exchange_rate_value;
                    } else {
                        $exchange_rate = $currency_active->settings->exchange_rate_value / $currency_default->settings->exchange_rate_value;
                    }

                    $price = $price * $exchange_rate;
                }
            }
        }

        return $price;
    }

    public function tc_change_product_price_display($symbol, $currency)
    {
        if (!is_admin() && !empty($_GET['currency'])) {
            $currency_get = $_GET['currency'];
            $client_api = new ClientApi();
            $client_data = $client_api->get_client_data();
            if (!empty($client_data)) {
                $client_data = $client_data->data;
                $currency_default = $client_data->currencies[0];
                $currency_active = array_filter($client_data->currencies, function ($var) use ($currency_get) {
                    return ($var->code == $currency_get);
                });
                $currency_active = !empty($currency_active) ? array_shift($currency_active) : null;
                if ($currency_active->code != $currency_default->code) {
                    $symbol = $currency_active->settings->symbol;
                }
            }
        }
        return $symbol;
    }

    function join_tc_post_to_WPQuery($join): string
    {
        global $wpdb;
        $lang = !empty($_GET['lang']) ? $_GET['lang'] : null;
        $table_name = $wpdb->prefix . 'transcy_relationships';
        return $join . " RIGHT JOIN {$table_name} ON {$wpdb->posts}.ID = {$table_name}.relationship_id AND {$table_name}.lang = '$lang' AND prefix='post'";
    }

    /**
     * Don't show post translation
     */
    public function posts_clauses_hide_tc_post($pieces)
    {
        global $wpdb;
        $table_name = $wpdb->prefix . 'transcy_relationships';
        $pieces['where'] .= " AND $wpdb->posts.id NOT IN (SELECT relationship_id FROM $table_name WHERE $wpdb->posts.id = $table_name.relationship_id AND prefix='post')";
        return $pieces;
    }

    /**
     * add terms_clauses hide duplicate term in admin
     * @param $pieces
     * @param $taxonomies
     * @param $args
     */
    function terms_clauses_tc_taxonomy_to_WPQuery($pieces, $taxonomies, $args)
    {
        global $wpdb;
        if (is_admin() || (wp_is_json_request() && strpos($_SERVER[ 'REQUEST_URI' ], '/wp-json/') !== false)) {
            $table_name = $wpdb->prefix . 'transcy_relationships';
            $pieces['where'] .= " AND t.term_id NOT IN (SELECT relationship_id FROM $table_name WHERE t.term_id = $table_name.relationship_id AND prefix='term')";
        }
        return $pieces;
    }
}
