<?php

/**
 * List api call from extent-app
 */

namespace Transcy\Api;

use Exception;
use Transcy\Helpers\WPQueryTranscy;
use Transcy\Helpers\WPTermQueryTranscy;

class ExtenAppApi extends BaseExtenApi
{
    public function register()
    {
        $funcs = array(
            'active_plugins',
            'get_resources',
            'get_resources_taxonomy',
            'clear_cache_storefront',
            'clear_cache_storefront_get',
            'get_free_languages'
        );

        foreach ($funcs as $func) {
            add_action('rest_api_init', array($this, $func));
        }
    }

    public function active_plugins()
    {
        $this->register_enpoint(
            'v1',
            'active-plugins',
            array(
                'methods' => 'GET',
                'callback' => array($this, 'active_plugins_func')
            )
        );
    }

    public function active_plugins_func()
    {
        $option = get_option('active_plugins', true);
        $data = [];
        foreach ($option as $op) {
            $data[] = $op;
        }
        return [
            'code' => 200,
            'status' => true,
            'message' => 'OK',
            'data' => $data
        ];
    }

    public function get_resources()
    {
        $this->register_enpoint(
            'v1',
            'resources',
            array(
                'methods' => 'GET',
                'callback' => array($this, 'get_resources_func')
            )
        );
    }

    public function get_resources_taxonomy()
    {
        $this->register_enpoint(
            'v1',
            'taxonomy-resources',
            array(
                'methods' => 'GET',
                'callback' => array($this, 'get_resources_func')
            )
        );
    }

    public function get_resources_func($req)
    {
        try {
            $params = $_GET;
            if (in_array($params['type'], ['post', 'page', 'product'])) {
                $args = array(
                    'is_translation' => true,
                    'post_type' => $params['type'],
                    'post_status' => 'publish',
                    'order' => 'ASC',
                    'orderby' => 'ID',
                    'posts_per_page' => !empty($params['limit']) ? $params['limit'] : 250,
                    'paged' => !empty($params['paged']) ? $params['paged'] : 1,
                );
                $query = new WPQueryTranscy($args);

                return [
                    'code' => 200,
                    'status' => true,
                    'message' => 'OK',
                    'data' => [
                        'resources' => $query->posts,
                        'total' => $query->found_posts,
                        'max_num_pages' => $query->max_num_pages,
                        'current_page' => $query->query['paged'],
                    ]
                ];
            }

            if (in_array($params['type'], ['category', 'product_cat'])) {

                $args = array(
                    'is_translation' => true,
                    'hide_empty' => false,
                    'taxonomy'   => $params['type'],
                );
                $list = (new WPTermQueryTranscy($args))->get_terms();

                if (!empty($list->errors)) {
                    $list = [];
                }

                return [
                    'code' => 200,
                    'status' => true,
                    'message' => 'OK',
                    'data' => [
                        'resources' => $list,
                        'total' => count($list),
                        'max_num_pages' => 1,
                        'current_page' => 1,
                    ]
                ];
            }
        } catch (Exception $ex) {
        }

        return [
            'code' => 502,
            'status' => false,
            'message' => 'Error',
            'data' => []
        ];
    }


    public function clear_cache_storefront()
    {
        $this->register_enpoint(
            'v1',
            'clear-cache-store-front',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'clear_cache_storefront_func')
            )
        );
    }

    public function clear_cache_storefront_get()
    {
        $this->register_enpoint(
            'v1',
            'clear-cache-store-front',
            array(
                'methods' => 'GET',
                'callback' => array($this, 'clear_cache_storefront_func')
            )
        );
    }

    public function clear_cache_storefront_func()
    {
        delete_option('transcy_client_data');

        return [
            'code' => 200,
            'status' => true,
            'message' => 'OK',
            'data' => null
        ];
    }


    public function get_free_languages()
    {
        $this->register_enpoint(
            'v1',
            'free-languages',
            array(
                'methods' => 'GET',
                'callback' => array($this, 'get_free_languages_func')
            )
        );
    }

    public function get_free_languages_func()
    {
        $data = $this->get_list_target_func();
        // wp_dump($data);
        return [
            'code' => 200,
            'status' => true,
            'message' => 'OK',
            'data' => (array)  $data
        ];
    }

    private function get_list_target_func()
    {
        $list = [];

        $default = get_option('transcy_lang_default');
        if(empty($default)){
            $default = [
                'en_name' => 'English',
                'short_name' => 'en',
                'native_name' => 'English',
                'slug' => 'en'
            ];
        }
        $defaultFormat = [
            'default' => true,
            'post_id' => null,
            'en_name' => $default['en_name'],
            'short_name' => $default['short_name'],
            'native_name' => $default['native_name'],
            'slug' => $default['slug'],
            'publish_status' => 1,
            'pin_status' => "0",
            'publish_date' =>'',
            'pin_date' => null,
            'created_date'=> null
        ];
        $list[] = $defaultFormat;

        $args_post = array(
            'post_type'  => 'transcy-lang',
            'post_status'   => 'any',
            'posts_per_page' => -1,
            'meta_query' => array(
                'relation' => 'AND',
                'pin_meta' => array(
                    'key'     => 'pin_meta',
                    'compare' => 'EXISTS',
                ),
                'pin_date' => array(
                    'key'     => 'pin_date',
                    'compare' => 'EXISTS',
                ),
            ),
            'orderby'  => array('pin_meta' => 'DESC', 'pin_date' => 'DESC')
        );
        $query_post = new \WP_Query($args_post);
  
        if ($query_post->have_posts()) {
            $i = 1;
            while ($query_post->have_posts()) {
                $query_post->the_post();

                $id_post = get_the_ID();
                $data_post_arg = [];
                $data_post_arg['default'] = false;
                $data_post_arg['post_id'] = $id_post;
                $data_post_arg['en_name'] = get_the_title();
                $data_post_arg['short_name'] = get_post_meta($id_post, 'short_name', true);
                $data_post_arg['native_name'] = get_post_meta($id_post, 'native_name', true);
                $data_post_arg['slug'] = get_post_meta($id_post, 'slug', true);
                $data_post_arg['publish_status'] = get_post_status($id_post) == 'publish' ? 1 : 0;
                $data_post_arg['pin_status'] = get_post_meta($id_post, 'pin_meta', true);
                $publish_date = date_create(get_post_meta($id_post, 'publish_date', true));
                $data_post_arg['publish_date'] = (get_post_status($id_post) == 'publish' ? date_format($publish_date, "M d, Y") . ' at ' . date_format($publish_date, "H:i:s a") : '');
                $data_post_arg['pin_date'] = get_post_meta($id_post, 'pin_date', true);
                $data_post_arg['created_date'] = get_the_date('Y/m/d h:i a');
                $i++;
                $list[] = $data_post_arg;
            }
        }
        wp_reset_postdata();

        return $list;
    }
}
