<?php

namespace Transcy\Api;
use Transcy\Admin\Options;

class SwitcherApi extends BaseApi {
	public function register() {
        $funcs = array(
            'get_list_option_switcher',
            'get_option_default_switcher',
            'update_option_switcher',
            'get_preview_target_lang'
        );
        
        foreach($funcs as $func) {
            add_action('rest_api_init', array($this , $func));
        }
    }

	/*
    * Get list all lang
    */
    public function get_list_option_switcher() {
    	$this->register_enpoint(
            'v1',
            'get-list-option-switcher',
            array(
                'methods' => 'GET',
	            'callback' => array($this, 'get_list_option_switcher_func')
            )
        );
    }

    public function get_list_option_switcher_func() {
    	require_once(TRANSCY_DIR_PATH . '/data/option-switcher.php');
    	return $data;
    }


    /*
    * Get option default switcher
    */
    public function get_option_default_switcher() {
        $this->register_enpoint(
            'v1',
            'get-option-default-switcher',
            array(
                'methods' => 'GET',
                'callback' => array($this, 'get_option_default_switcher_func')
            )
        );
    }

    public function get_option_default_switcher_func() {
        return get_option('transcy_option')['switcher'];
    }


    /*
    * Update option switcher
    */
    public function update_option_switcher() {
        $this->register_enpoint(
            'v1',
            'update-option-switcher',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'update_option_switcher_func')
            )
        );
    }

    public function update_option_switcher_func($req) {
        $data = $req->get_query_params();
        $option = new Options();
        $options_saved = get_option('transcy_option');
        foreach($data as $key => $val) {
            $options_saved['switcher'][$key] = $val;
        }

        $option->set_option('transcy_option', $options_saved);
        return wp_send_json_success([
            'message' => 'OK'
        ]);
    }

    /*
    * Get preview target lang switcher
    */
    public function get_preview_target_lang() {
        $this->register_enpoint(
            'v1',
            'get-preview-target-lang-switcher',
            array(
                'methods' => 'GET',
                'callback' => array($this, 'get_preview_target_lang_func')
            )
        );
    }

    public function get_preview_target_lang_func() {
        $list = [];
        $lang_default = is_array(get_option('transcy_lang_default')) ?  get_option('transcy_lang_default') :  json_decode(get_option('transcy_lang_default'), true);
        $args_post = array(
            'post_type'  => 'transcy-lang',
            'post_status'   => 'publish',
            'orderby' => 'date',
            'order'   => 'DESC',
            'posts_per_page' => -1,
            'meta_key'        => 'pin_meta',
            'orderby'         => array('meta_value_num' => 'DESC', 'post_date' => 'DESC')
        );
        $query_post = new \WP_Query($args_post);
        if($query_post->have_posts()) {
            $i=0;while($query_post->have_posts()) {
                $query_post->the_post();

                $id_post = get_the_ID();
                $list[$i]['post_id'] = $id_post;
                $list[$i]['en_name'] = get_the_title();
                $list[$i]['short_name'] = get_post_meta($id_post, 'short_name', true);
                $list[$i]['native_name'] = get_post_meta($id_post, 'native_name', true);
                $list[$i]['slug'] = get_post_meta($id_post, 'slug', true);
                $list[$i]['publish_status'] = get_post_status($id_post) == 'publish' ? 1 : 0;
                $list[$i]['pin_status'] = get_post_meta($id_post, 'pin_meta', true);
                $list[$i]['created_date'] = get_the_date('Y/m/d h:i a');
            $i++;}
        }
        wp_reset_postdata();
        
        if(in_array($lang_default['slug'], $list)) {
            $list[$query_post->found_posts] = $lang_default['slug'];
        }

        return  array_unique($list, SORT_REGULAR);
    }
}