<?php

namespace Transcy\Api;

use Transcy\Model\RelationshipLanguage;

class TranslateApi extends BaseExtenApi
{
    const  POST_TYPE = 'tc_translate';

    public function register()
    {
        //add_filter('init', array($this, 'add_custom_post_type_translation'));
        add_action('rest_api_init', array($this, 'create_post_translate'));
        add_action('rest_api_init', array($this, 'create_term_translate'));
        add_action('rest_api_init', array($this, 'refresh_relationship_table'));
    }

    /**
     * add post type of post translate
     * @return void
     */
    public function add_custom_post_type_translation()
    {
        register_post_type(self::POST_TYPE,
            array(
                'public' => true,
                'has_archive' => false,
                "show_in_menu" => false,
                'rewrite' => array('slug' => 'blog', 'with_front' => FALSE),
                'show_in_rest' => true,
            )
        );
    }

    public function create_post_translate()
    {
        $this->register_enpoint(
            'v1',
            'create-or-update-post-translate',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'post_translate_api_func')
            )
        );
    }

    /**
     * insert post translate into database
     * @param \WP_REST_Request $request
     * @return mixed
     */
    public function post_translate_api_func(\WP_REST_Request $request): mixed
    {
        $validate = [];
        $responses = json_decode($request->get_body());
        foreach ($responses as $res) {
            $post = get_post($res->post_id);
            if (isset($post) && $post != null) {
                $translationsRelationship = new RelationshipLanguage();
                $translatePostRelationship = $translationsRelationship->get($post->ID, 'post', $res->locale);
                if (count($translatePostRelationship) > 0) {
                    $translatePost = get_post($translatePostRelationship[0]->relationship_id);
                    $newPostId = wp_update_post($this->addArgs($translatePost, $res, true));
                    $this->update_post_metadata_func($res->post_id, $newPostId);
                    if ($newPostId == 0 || $newPostId instanceof \WP_Error) {
                        $validate['failed'][] = $post->ID;
                    } else {
                        $validate['success'][] = $post->ID;
                    }
                } else {
                    $this->create_post_translate_func($post, $res, $validate);
                }

            } else {
                $validate['failed'][] = $res->post_id;
            }
        }

        return wp_send_json_success($validate);
    }

    public function create_term_translate()
    {
        $this->register_enpoint(
            'v1',
            'create_term_translate',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'translate_term_func')
            )
        );
    }

    /**
     * insert or update term translate into database
     * @param \WP_REST_Request $request
     * @return mixed
     */
    public function translate_term_func(\WP_REST_Request $request): mixed
    {
        $validate = [];
        $responses = json_decode($request->get_body());
        foreach ($responses as $res) {
            if ((isset($res->name) && trim($res->name) != '') && (isset($res->locale) && trim($res->locale) != '')) {
                $translationsRelationship = new RelationshipLanguage();
                $taxonomy = trim($res->taxonomy) ?? 'category';
                $lang = trim($res->locale);
                $updateFlag = false;

                if (term_exists((int)$res->id)) {
                    $originTerm = get_term((int)$res->id, $taxonomy);
                    $termTranslationsRelationship = $translationsRelationship->get($originTerm->term_id, 'term', $lang);
                    if (count($termTranslationsRelationship) > 0) {
                        $updateFlag = true;
                        $res->term_id = $termTranslationsRelationship[0]->relationship_id;
                    }

                    $res->parent = $originTerm->parent;
                    $term_id = $this->wp_translate_term_func($res, $res->locale, $updateFlag);
                }
            }

            if (!isset($term_id) || $term_id == 0) {
                $validate['failed'][] = $res->id;
            } else {
                $validate['success'][] = $res->id;
            }

        }
        return wp_send_json_success($validate);
    }

    public function refresh_relationship_table()
    {
        $this->register_enpoint(
            'v1',
            'refresh-tc-relationship-table',
            array(
                'methods' => 'GET',
                'callback' => array($this, 'refresh_transcy_relationship_table_fnc')
            )
        );
    }

    public function refresh_transcy_relationship_table_fnc()
    {
        global $wpdb;
        $table_name = $wpdb->prefix . 'transcy_relationships';
        $result= $wpdb->query( "DROP TABLE IF EXISTS {$table_name}");
        return wp_send_json(['Refresh table'=> $result]);
    }

    /**
     * @param \WP_POST $post
     * @param object $res
     * @param array $validate
     */
    public function create_post_translate_func(\WP_POST $post, object $res, array &$validate): void
    {
        global $wpdb;
        $translationsRelationship = new RelationshipLanguage();
        $mainPostId = $post->ID;

        // Insert the post into the database
        $newPostId = wp_insert_post($this->addArgs($post, $res));

        if ($newPostId == 0 || $newPostId instanceof \WP_Error) {
            $validate['failed'][] = $mainPostId;
            return;
        }

        // Insert taxonomies, terms
        // returns array of taxonomy names for post type, ex array("category", "post_tag");
        $taxonomies = get_object_taxonomies($post->post_type);
        foreach ($taxonomies as $taxonomy) {
            $terms = [];
            $post_terms = wp_get_object_terms($mainPostId, $taxonomy, array('fields' => 'slugs'));
            if (is_array($post_terms) && count($post_terms) > 0) {
                foreach ($post_terms as $post_term) {
                    $originTerm = get_term_by('slug', $post_term, $taxonomy);
                    if ($originTerm instanceof \WP_Term) {
                        $termTranslationsRelationship = $translationsRelationship->get($originTerm->term_id, 'term', $res->locale);
                        if (count($termTranslationsRelationship) > 0) {
                            $terms[] = $termTranslationsRelationship[0]->relationship_id;
                        } else {
                            $terms[] = $post_term;
                        }
                    }
                }
            }
            wp_set_object_terms($newPostId, $terms, $taxonomy, false);
        }

        $translationsRelationship->add($mainPostId, $newPostId, 'post', $res->locale);

        // duplicate all post meta just
        $post_meta_infos = $wpdb->get_results("SELECT meta_key, meta_value FROM $wpdb->postmeta WHERE post_id=$mainPostId");
        if (count($post_meta_infos) != 0) {
            $sql_query = "INSERT INTO $wpdb->postmeta (post_id, meta_key, meta_value) ";
            foreach ($post_meta_infos as $meta_info) {
                $meta_key = $meta_info->meta_key;
                if ($meta_key == '_wp_old_slug') continue;
                $meta_value = addslashes($meta_info->meta_value);
                $sql_query_sel[] = "SELECT $newPostId, '$meta_key', '$meta_value'";
            }
            $sql_query .= implode(" UNION ALL ", $sql_query_sel);
            $wpdb->query($sql_query);
        }

        $validate['success'][] = $mainPostId;
    }

    /**
     * @param $post_id
     * @param $new_post_id
     * @return void
     */
    function update_post_metadata_func($post_id, $new_post_id) {
        $data = get_post_custom($post_id);

        foreach ($data as $key => $values) {
            foreach ($values as $value) {
                update_post_meta($new_post_id, $key, maybe_unserialize($value));
            }
        }
    }

    /**
     * add params to translate post
     * @param \WP_POST $post
     * @param object $res
     * @param bool $updateFlag
     * @return array
     */
    public function addArgs(\WP_POST $post, object $res, bool $updateFlag = false): array
    {
        $args = array(
            'post_content' => $res->content,
            'post_excerpt' => $res->excerpt,
            'post_name' => $res->slug,
            'post_title' => $res->title,
        );

        if ($updateFlag) {
            $args['ID'] = $post->ID;
        } else {
            $args['menu_order'] = $post->menu_order;
            $args['to_ping'] = $post->to_ping;
            $args['post_type'] = $post->post_type;
            $args['post_status'] = $post->post_status;
            $args['post_password'] = $post->post_password;
            $args['post_parent'] = $post->post_parent;
            $args['post_author'] = $post->post_author;
            $args['ping_status'] = $post->ping_status;
            $args['comment_status'] = $post->comment_status;
        }

        return $args;
    }

    /**
     * Insert or update translate term function
     * @param object|array $args
     * @param string $lang
     * @param bool $updateFlag
     * @param bool $wp_error
     * @return int|\WP_Error
     */
    function wp_translate_term_func($args, string $lang, bool $updateFlag = false, bool $wp_error = false)
    {
        $translationsRelationship = new RelationshipLanguage();
        $term_defaults = array(
            'term_id' => 0,
            'taxonomy' => 'category',
            'name' => '',
            'description' => '',
            'slug' => '',
            'parent' => 0,
        );

        if (is_object($args)) {
            $args = (array)$args;
        }
        $args = wp_parse_args($args, $term_defaults);

        $term_id = (int)$args['term_id'];
        $origin_term_id = $args['id'];
        $name = $args['name'];
        $description = $args['description'];
        $slug = $args['slug'];
        $taxonomy = $args['taxonomy'];
        $parent = (int)$args['parent'];

        // Parent term has translation
        if ($parent > 0 && term_exists($parent, $taxonomy) && !term_is_ancestor_of($term_id, $parent, $taxonomy)) {
            $parentTermTranslationsRelationship = $translationsRelationship->get($parent, 'term', $lang);
            if (count($parentTermTranslationsRelationship) > 0) {
                $parent = $parentTermTranslationsRelationship[0]->relationship_id;
            }
        }

        $args = compact('name', 'slug', 'parent', 'description');
        if ($updateFlag) {
            $term = wp_update_term($term_id, $taxonomy, $args);
        } else {
            $term = wp_insert_term($name, $taxonomy, $args);
            $translationsRelationship->add($origin_term_id, $term['term_id'], 'term', $lang);
        }

        if (is_wp_error($term)) {
            if ($wp_error) {
                return $origin_term_id;
            } else {
                return 0;
            }
        }
        return $term['term_id'];
    }
}

