<?php

namespace Transcy\Api;

use Transcy\Admin\Options;
use Transcy\Api\AppApi\AppToken;
use Transcy\Base\Language;
use Transcy\Helpers\Info;

class WebhookApi extends BaseApi
{
    public function register()
    {
        $funcs = array(
            'get_admin_email',
            'register_user_info',
            'auth_check_register',
            'update_app_apikey',
            'get_info_site',
            'get_token'
        );

        foreach ($funcs as $func) {
            add_action('rest_api_init', array($this, $func));
        }
    }

    /*
    * Get admin email
    */
    public function get_admin_email()
    {
        $this->register_enpoint(
            'v1',
            'get-admin-email',
            array(
                'methods' => 'GET',
                'callback' => array($this, 'get_admin_email_func')
            )
        );
    }

    public function get_admin_email_func()
    {
        return get_option('admin_email');
    }

    /*
    * Register user info when submit form
    */
    public function register_user_info()
    {
        $this->register_enpoint(
            'v1',
            'register-user-info',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'register_user_info_func')
            )
        );
    }

    public function register_user_info_func($req)
    {
        $response['email'] = $req['email'];
        $response['url'] = $req['url'];

        $option = new Options();
        if (!$option->check_option_already('transcy_user_info')) {
            $option->set_option('transcy_user_info', $response);
            return wp_send_json_success([
                'message' => 'OK'
            ]);
        } else {
            return wp_send_json_error([
                'message' => 'User info already!'
            ]);
        }
    }

    /*
    * Check User has registed
    */
    public function auth_check_register()
    {
        $this->register_enpoint(
            'v1',
            'check-register',
            array(
                'methods' => 'GET',
                'callback' => array($this, 'auth_check_register_func')
            )
        );
    }

    public function auth_check_register_func()
    {
        $option = new Options();
        $check = 0;
        if (!empty($option->get_option('transcy_user_info')) && !empty($option->get_option('transcy_app_apikey'))) {
            $check = 1;
        }
        return $check;
    }

    /*
    * Update App apikey when register user at dashboard
    */
    public function update_app_apikey()
    {
        $this->register_enpoint(
            'v1',
            'update-app-apikey',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'update_app_apikey_func')
            )
        );
    }

    public function update_app_apikey_func($req)
    {
        $apikey = $req['apiKey'];
        $option = new Options();

        // if (!$option->check_option_already('transcy_app_apikey')) {
        $option->set_option('transcy_app_apikey', $apikey);
        // }
    }

    /*
    * Get info site
    */
    public function get_info_site()
    {
        $this->register_enpoint(
            'v1',
            'get-info-site',
            array(
                'methods' => 'GET',
                'callback' => array($this, 'get_info_site_func')
            )
        );
    }

    public function get_info_site_func()
    {
        $info = new Info();
        $option = new Options();
        $language = new Language();
        $tc_version = $info->get_tc_version();
        $wp_version = $info->get_wp_version();
        $locale = $language->get_wp_admin_locale();
        $woo_default_currency = '';

        if ($option->check_option_already('woocommerce_currency')) {
            $woo_default_currency = $option->get_option('woocommerce_currency');
        }

        return array(
            'default_language_code' => $locale,
            'default_currency_code' => $woo_default_currency,
            'tc_version' => $tc_version,
            'wp_version' => $wp_version
        );
    }

    /*
    * Get info site
    */
    public function get_token()
    {
        $this->register_enpoint(
            'v1',
            'get-token',
            array(
                'methods' => 'GET',
                'callback' => array($this, 'get_token_func')
            )
        );
    }

    public function get_token_func()
    {
        $appToken = new AppToken();
        $token = $appToken->generate_token();

        return array(
            'token' => $token,
        );
    }
}
