<?php

namespace Transcy\Base;

use Transcy\Api\AppApi\ClientApi;
use Transcy\Helpers\Common;
use Transcy\Api\LangApi;
use Transcy\Admin\Options;

class Language
{
    public function get_page_link_translated($slug_lang = '', $link = '')
    {
        $helper = new Common();
        $lang_api = new LangApi();
        $link = $helper->removeParam($link, 'lang');
        $lang_default = is_array($lang_api->get_lang_default_func()) ? $lang_api->get_lang_default_func()['slug'] : json_decode($lang_api->get_lang_default_func(), true)['slug'];

        if ($slug_lang == $lang_default) {
            return $link;
        } else {
            $url = $helper->add_param_to_url($link, 'lang', $slug_lang);
        }
        return ($slug_lang == $lang_default) ? $helper->removeParam($url, 'lang') : $url;
    }

    public function get_lang_current()
    {
        return isset($_GET['lang']) ? sanitize_text_field($_GET['lang']) : '';
    }

    public function get_name_by_slug($slug)
    {
        $lang_api = new LangApi();
        $options = new Options();
        $list_lang = $lang_api->get_list_lang_func();
        $switcher_option = $options->get_option('transcy_option')['switcher'];
        $eng_name = $switcher_option['english_name'];

        foreach ($list_lang as $lang) {
            if ($lang['slug'] == $slug) {
                switch ($eng_name) {
                    case 'Short name':
                        return strtoupper($lang['short_name']);
                        break;
                    case 'Native name':
                        return $lang['native_name'];
                        break;
                    case 'Only flag':
                        return 'Only flag';
                        break;
                    default:
                        return $lang['en_name'];
                }
            }
        }

        return;
    }

    public function check_lang_exist_by_slug($slug)
    {
        $lang_api = new LangApi();
        $found = 0;
        $list_lang = $lang_api->get_list_lang_func();
        foreach ($list_lang as $lang) {
            if ($lang['slug'] == $slug) $found = 1;
        }

        return $found;
    }

    public function get_flag_url_by_slug($slug)
    {
        return APP_URL . '/flags/' . $slug . '.svg';
    }

    /*
    * V2 get link translated
    */
    public function v2_get_page_link_translated($slug_lang = '', $link = '', $lang_default = '')
    {
        $helper = new Common();
        $lang_api = new LangApi();
        $link = $helper->removeParam($link, 'lang');

        if ($slug_lang == $lang_default) {
            return $link;
        } else {
            $url = $helper->add_param_to_url($link, 'lang', $slug_lang);
            return $url;
        }
    }

    public function getLangDefaultData(): array
    {
        $client_api = new ClientApi();
        $client_data = $client_api->get_client_data();
        $lang = $this->get_lang_current();
        if (!empty($client_data)) {
            $client_data = $client_data->data;
            $lang_info = array_filter($client_data->languages, function ($var) use ($lang) {
                return ($var->code == $lang);
            });
            return ['info' => array_shift($lang_info), 'default_language' => $client_data->default_language];
        }
        return [];
    }

    public function get_wp_admin_locale()
    {
        $locale = get_locale();
        $explode  = explode('_', $locale);
        // wp_dump($explode);
        return $explode[0];
    }
}
