<?php

namespace Transcy\Base;

use Transcy\Admin\Options;
use Transcy\Api\AppApi\AppToken;
use Transcy\Helpers\Info;
use Transcy\Base\Curl;

/**
 * Transcy Tracking Class
 *
 * @package Transcy\Base
 * @author TanNV, QuanLM
 */
class Tracking
{
    public function register()
    {
        global $pagenow;
        if (is_admin() && $pagenow == 'index.php') {
            $this->tracking_handle();
        }
    }

    public function get_email()
    {
        $option = new Options();

        if ($option->check_option_already('transcy_user_info')) {
            $user_info = $option->get_option('transcy_user_info');

            return $user_info['email'];
        } else {
            return get_option('admin_email');
        }
    }


    public function tracking_handle($status = 1)
    {
        $info = new Info();
        $curl = new Curl();
        $option = new Options();
        $language = new Language();

        $domain = $info->get_domain();
        $email = $this->get_email();
        $locale = $language->get_wp_admin_locale();
        $woo_default_currency = '';

        if ($option->check_option_already('woocommerce_currency')) {
            $woo_default_currency = $option->get_option('woocommerce_currency');
        }

        // Push tracking
        $header = [
            "Content-Type: application/json"
        ];
        $data = json_encode([
            "domain" => $domain,
            "email" => $email,
            "status" => (int)$status,
            'default_language_code' => $locale,
            'default_currency_code' => $woo_default_currency
        ]);

        $curl->call_api(APP_API_URL . '/api/register', 'POST', $data, $header);
    }

    /*
     * Tracking Event 
     *
     * @param status: 1/ 2/ 3
     * @param event: uninstall/ newinstall/ reinstall/ active/ deactive
     */
    public function trackingEvent($status, $event)
    {
        $app_token = new AppToken();

        $info = new Info();
        $curl = new Curl();
        $domain = $info->get_domain();
        $token = $app_token->generate_token($domain);

        // Push tracking
        $header = array(
            "Content-Type: application/json",
            "Authorization: Bearer " . $token,
        );
        $data = json_encode([
            "domain" => $domain,
            "status" => $status,
            "event" => $event
        ]);

        /*
        * New endpoint for premium plugin 
        */
        if ($event === "uninstalled") {
            $response = $curl->call_api(APP_API_URL . '/api/webhooks/uninstalled', 'POST', $data, $header);
        } else {
            $response = $curl->call_api(APP_API_URL . '/api/webhooks/installation', 'POST', $data, $header);
        }

        error_log("[TRANSCY][TRACKING] {$event}: " . json_encode([$response]));
    }

    /*
     * Tracking on Woocommerce
     * currency, version ... 
     */
    public function trackingWoocommerce($lang, $new_currency)
    {
        $app_token = new AppToken();
        $info = new Info();
        $curl = new Curl();

        $domain = $info->get_domain();
        $token = $app_token->generate_token($domain);

        $header = array(
            "Content-Type: application/json",
            "Authorization: Bearer " . $token
        );
        $data = json_encode([
            "default_language_code" => $lang,
            "default_currency_code" => $new_currency
        ]);

        $curl->call_api(APP_API_URL . '/api/clients/current', 'PUT', $data, $header);
    }
}
