<?php

namespace Transcy\Front;

use Transcy\Helpers\Common;
use Transcy\Base\Language;
use Transcy\Api\LangApi;
use Transcy\Api\AppApi\ClientApi;
use Transcy\Model\RelationshipLanguage;

class Front
{
    public function register()
    {
        add_action('init', array($this, 'enable_settings_themes'));
        add_action('template_redirect', array($this, 'redirect_invalid'));
        add_filter('wpseo_robots', array($this, 'noindex_cs_post'), 999);
    }

    /**
     * Enable jquery if themes not include already
     */
    public function enable_settings_themes()
    {
        wp_enqueue_script("jquery");
    }

    /**
     * Redirect invalid
     */
    public function redirect_invalid()
    {
        $helper = new Common();
        $lang_api = new LangApi();
        $client_api = new ClientApi();
        $baseLanguage = new Language();

        $found = 0;
        $lang = $baseLanguage->get_lang_current();
        $client_data = $client_api->get_client_data();
        if (isset($client_data->data)) {
            $client_data = $client_data->data;
        } else {
            return false;
        }

        $lang_default = $lang_api->get_lang_default_func();
        $lang_default = is_array($lang_default) ? $lang_default['slug'] : json_decode($lang_default, true)['slug'];
        if ($lang_default == $lang) {
            $found = 1;
        }

        $v2_target_langs = $client_data->languages;
        $list_target_lang = array_filter($v2_target_langs, function ($var) {
            return ($var->is_published == 1);
        });
        if (!empty($list_target_lang)) {
            foreach ($list_target_lang as $l) {
                if ($l->locale == $lang) {
                    $found = 1;
                }
            }
        }

        $current_url = $helper->get_url_current();
        if ((strpos($current_url, '?lang') || strpos($current_url, '&lang')) && $found == 0) {
            wp_redirect(home_url());
            die();
        }

        if (!empty($_GET['fbclid']) && strpos($helper->get_url_current(), $_GET['fbclid'])) {
            $helper = new Common();
            $new_url = $helper->removeParam($helper->get_url_current(), 'fbclid');
            wp_redirect($new_url);
            die();
        }

        // Redirect post
        $id_current_post = get_the_ID();
        if (function_exists('is_shop')) {
            $this->wooShopPageRedirect($id_current_post);
        }

        if (empty($lang) || $lang_default == $lang) {
            $this->redirectToOriginPost($id_current_post);
        } else {
            $lang_active_info = array_filter($client_data->languages, function ($var) use ($lang) {
                return ($var->code == $lang);
            });
            $lang_active_info = array_shift($lang_active_info);

            if ($lang_active_info->type === 1) {
                $this->redirectToOriginPost($id_current_post);
            } else {
                $this->redirectToTcPost($id_current_post, $lang);
            }
        }
    }

    /**
     * @param int $postId
     * @return void
     */
    public function redirectToOriginPost(int $postId)
    {
        $relationshipTranslation = new RelationshipLanguage();
        $originPost = $relationshipTranslation->getOriginId($postId, 'post');
        if (is_array($originPost)) {
            wp_redirect(add_query_arg($_GET, get_permalink($originPost['id'])));
            die();
        }
    }

    /**
     * @param int $postId
     * @param string $lang
     * @return void
     */
    public function redirectToTcPost(int $postId, string $lang)
    {
        $relationshipTranslation = new RelationshipLanguage();
        $translatePostRelationship = $relationshipTranslation->get($postId, 'post', $lang);
        if (count($translatePostRelationship) > 0) {
            wp_redirect(add_query_arg($_GET, get_permalink($translatePostRelationship[0]->relationship_id)));
            die();
        }
    }

    function wooShopPageRedirect(int $postId)
    {
        // woo shop page not redirect
        if (is_shop()) {
            return false;
        }

        if (is_page()) {
            $shop = get_option('woocommerce_shop_page_id');
            $relationshipTranslation = new RelationshipLanguage();
            $originPost = $relationshipTranslation->getOriginId($postId, 'post');
            if (!is_null($shop) && is_array($originPost)) {
                if ((int)$shop === (int)$originPost['id']) {
                    wp_redirect(add_query_arg($_GET, get_permalink($originPost['id'])));
                    die;
                }
            }
        }
    }

    /**
     * Disable meta
     */
    public function remove_box_seo_cs_post()
    {
        remove_meta_box('wpseo_meta', 'transcy-lang', 'normal');
    }

    public function noindex_cs_post($string = "")
    {
        if (is_singular('transcy-lang')) {
            $string = "noindex, nofollow";
        }

        return $string;
    }
}
