<?php

namespace Transcy\Front;

use Transcy\Admin\Options;
use Transcy\Base\Language;
use Transcy\Helpers\Common;
use Transcy\Api\AppApi\AppToken;
use Transcy\Api\AppApi\ClientApi;
use Transcy\Base\Currency;

class Switcher
{
    public function register()
    {
        if (!$this->get_status()) return false;
        add_action('wp_head', array($this, 'check_version'));
    }

    /**
     * Check version
     */
    function check_version()
    {
        $client_api = new ClientApi();

        $client_data = $client_api->get_client_data();
        if (!isset($client_data->data)) {
            // return $this->render_switcher();
            // echo 'Please upgrage plugin version';
        } else { // Upgrade version
            return $this->v2_render_switcher($client_data->data);
        }
    }



    /**
     * Check switcher status (Show/Hide)
     */
    public function get_status()
    {
        $options = new Options();
        $option_saved = $options->get_option('transcy_option');
        if (!empty($option_saved['switcher']['visible_switch']) && $option_saved['switcher']['position_show'] == 'Everyone') {
            return 1;
        } else {
            return 0;
        }
    }

    public function get_slug_lang_choosed($language)
    {
        $slug = $language->code;

        return $slug;
    }


    public function get_name_lang_choosed($language)
    {
        $options = new Options();
        $switcher_option = $options->get_option('transcy_option')['switcher'];
        $eng_name = $switcher_option['english_name'];

        switch ($eng_name) {
            case 'Short name':
                $name =  strtoupper($language->short_name);
                break;
            case 'Native name':
                $name = $language->native_name;
                break;
            case 'Only flag':
                $name = '';
                break;
            default:
                $name = $language->name_en;
        }

        return $name;
    }

    public function get_name_currency($currency_active)
    {
        $options    = new Options();
        $switcher_option = $options->get_option('transcy_option')['switcher'];
        $label_currency = $switcher_option['label_currency'];
        $name_currency = '';

        foreach ($label_currency as &$value) {
            if ($value == 'Symbol') {
                $name_currency .= ' (' . $currency_active->settings->symbol . ')';
            }
            if ($value == 'Name') {
                $name_currency .= ' ' . $currency_active->settings->name;
            }
            if ($value == 'Code') {
                $name_currency .= ' ' . $currency_active->settings->custom_code;
            }
        }
        return trim($name_currency);
    }



    /*
    ** V2 render switcher
    */
    public function v2_render_switcher($client_data)
    {
        $options    = new Options();
        $lang        = new Language();
        $currencyObj = new Currency();
        $helper      = new Common();
        $client_api = new ClientApi();
        $self = $this;
        $switcher_option = $options->get_option('transcy_option')['switcher'];

        //language config
        $is_show_lang = !empty($switcher_option['is_show_lang']) ? $switcher_option['is_show_lang'] : true;
        $is_flag = $switcher_option['is_flag'];
        $eng_name = $helper->convert_string_to_slug($switcher_option['english_name']);

        //config
        $position_float = $switcher_option['position_float'];
        $arrow_icon = $helper->convert_string_to_slug($switcher_option['arrow_icon']);
        $effect = $helper->convert_string_to_slug($switcher_option['effect']);
        $hover_active = $helper->convert_string_to_slug($switcher_option['hover_active']);
        $flag_style = $helper->convert_string_to_slug($switcher_option['flag_style']);
        $flag_size = $helper->convert_string_to_slug($switcher_option['flag_size']);
        $divider_format = !empty($switcher_option['divider_format']) ? $switcher_option['divider_format'] : false;


        //currency config
        $is_show_currency = !empty($switcher_option['is_show_currency'])  ? $switcher_option['is_show_currency'] : false;
        $is_flag_currency = !empty($switcher_option['is_flag_currency']) ? $switcher_option['is_flag_currency'] : false;
        $label_currency = !empty($switcher_option['label_currency']) ? $switcher_option['label_currency'] : false;

        //select lang
        $lang_default = $client_data->default_language;
        $target_lang = $client_data->languages;
        $target_lang = array_filter($target_lang, function ($var) {
            return ($var->is_published == 1);
        });
        $get_lang = !empty($lang->get_lang_current()) ? $lang->get_lang_current() : $lang_default->locale;
        $lang_active = array_filter($client_data->languages, function ($var) use ($get_lang) {
            return ($var->code == $get_lang);
        });
        $lang_active  = array_shift($lang_active);

        // Check if language has param
        if (!empty($lang->get_lang_current())) {
            // Delete language current
            foreach ($target_lang as $k => $v) {
                if ($v->locale == $lang->get_lang_current()) {
                    unset($target_lang[$k]);
                }
            }

            // Add language default
            array_unshift($target_lang, $lang_default);
        }

        //select currency
        $target_currencies = array_filter($client_data->currencies, function ($var) {
            return ($var->is_published || $var->is_default);
        });
        $currency_default = !empty($client_data->currencies) ? $client_data->currencies[0] : null;
        $currency_active =  $this->v2_get_currency_default($client_data);
        $exchange_rate = $currency_active->settings->exchange_rate_value;

        if ($is_show_lang == 1 && $is_show_currency == 0) {
            require_once(TRANSCY_TEMPLATES_FRONT . "/switcher-lang.php");
        }
        if ($is_show_lang == 0 && $is_show_currency == 1) {
            require_once(TRANSCY_TEMPLATES_FRONT . "/switcher-currency.php");
        }
        if ($is_show_lang == 1 && $is_show_currency == 1) {
            require_once(TRANSCY_TEMPLATES_FRONT . "/switcher-basic.php");
        }
    }


    public function v2_get_currency_default($client_data)
    {

        if (!empty($_GET['currency'])) {
            foreach ($client_data->currencies as $currency) {
                if ($currency->code == $_GET['currency']) {
                    return $currency;
                    break;
                }
            }
        }
        $data = $client_data->currencies[0];

        return $data;
    }
}
