<?php

namespace Transcy\Model;
class RelationshipLanguage
{
    protected string $table_name = 'transcy_relationships';
    protected array $prefix;

    public function __construct()
    {
        global $wpdb;
        $this->table_name = $wpdb->prefix . $this->table_name;
        $this->prefix = ['post', 'term'];
    }

    /**
     * @return array
     */
    public function getPrefix(): array
    {
        return $this->prefix;
    }

    function creating_transcy_relationship_tables()
    {
        global $wpdb;
        if ($wpdb->get_var("SHOW TABLES LIKE '" . $this->table_name . "'") != $this->table_name) {
            $sql = "CREATE TABLE IF NOT EXISTS $this->table_name(
                id mediumint(9) NOT NULL,
                relationship_id mediumint(9) NOT NULL,
                prefix VARCHAR(255) NOT NULL,
                lang VARCHAR(255) NOT NULL,
                PRIMARY KEY(id, relationship_id, prefix, lang))";

            if (!function_exists('dbDelta')) {
                require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
            }

            dbDelta($sql);
            echo "Tables created...";
            update_option('tables_created', true);
        }
    }

    /**
     * @param int $origin_id
     * @param int $translation_id
     * @param string $type
     * @param string $lang
     * @return bool|int|\mysqli_result|resource|null
     */
    public function add(int $origin_id, int $translation_id, string $type, string $lang)
    {
        global $wpdb;
        return $wpdb->insert(
            $this->table_name,
            array(
                'id' => $origin_id,
                'relationship_id' => $translation_id,
                'prefix' => $type,
                'lang' => $lang,
            )
        );
    }

    /**
     * @param int $origin_id
     * @param string $type [post, term]
     * @param string $lang
     * @return array|object|\stdClass[]|null
     */
    public function get(int $origin_id, string $type, string $lang = '')
    {
        global $wpdb;
        $sql = "SELECT * FROM $this->table_name WHERE id=$origin_id AND prefix='$type'";
        if ($lang != '') {
            $sql .= " AND lang='$lang'";
        }
        return $wpdb->get_results($sql);
    }

    /**
     * @param int $relationship_id
     * @param string $type
     * @return array|null
     */
    public function getOriginId(int $relationship_id, string $type)
    {
        global $wpdb;
        $result = $wpdb->get_results("SELECT * FROM $this->table_name WHERE relationship_id=$relationship_id AND prefix='$type'", ARRAY_A);
        if (is_array($result) && count($result) > 0) {
            return $result[0];
        }
        return null;
    }

    public function getByType(string $type)
    {
        global $wpdb;
        return $wpdb->get_results("SELECT * FROM $this->table_name WHERE prefix='$type'", ARRAY_A);
    }
}
