<?php
/*
Plugin Name: Transcy
Plugin URI: https://onecommerce.io/transcy/?utm_source=transcyphp&utm_medium=plugin-uri&utm_campaign=wordpress-tc
Description: Make your website multilingual easily with no coding. Instantly translate between languages with the Google Translate API.
Version: 2.1.1
Author: OneCommerce
Author URI: https://onecommerce.io/transcy/?utm_source=transcyphp&utm_medium=author-uri&utm_campaign=wordpress-tc
Text Domain: transcy
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Require once the Composer Autoload
if (file_exists(dirname(__FILE__) . '/vendor/autoload.php')) {
    require_once dirname(__FILE__) . '/vendor/autoload.php';
    require_once plugin_dir_path(__FILE__) . '/env.php';
}

define('TRANSCY_DIR', __DIR__);
define('TRANSCY_FILE', __FILE__);
define('TRANSCY_NAME', 'Transcy');
define('TRANSCY_VERSION', '1.0');
define('TRANSCY_URL', plugins_url(basename(dirname(__FILE__))));
define('TRANSCY_ASSETS_FOLDER', TRANSCY_URL . '/assets');
define('TRANSCY_DIR_PATH', plugin_dir_path(__FILE__));
define('TRANSCY_ASSETS_FOLDER_PATH', TRANSCY_DIR_PATH . '/assets');
define('TRANSCY_LIBS', TRANSCY_URL . '/assets/lib');
define('TRANSCY_TEMPLATES', TRANSCY_DIR_PATH . '/templates');
define('TRANSCY_TEMPLATES_ADMIN', TRANSCY_TEMPLATES . '/admin');
define('TRANSCY_TEMPLATES_FRONT', TRANSCY_TEMPLATES .'/front');


use Transcy\Api\AppApi\AppToken;
use Transcy\Helpers\Info;
use Transcy\Main;
use Transcy\Base\Active;
use Transcy\Base\Deactivate;
use Transcy\Base\Uninstall;

function transcy_plugin_loaded() {
    $main = new Main();
    $main->run_services();
}
add_action('plugins_loaded', 'transcy_plugin_loaded');


/**
 * The code that runs when plugin activation
 */
function transcy_active_plugin() {
    $active = new Active();
    $active->load();
}
register_activation_hook(TRANSCY_FILE, 'transcy_active_plugin');

/**
 * The code that runs when plugin deactivate
 */
function transcy_deactivate_plugin() {
    $deactivate = new Deactivate();
    $deactivate->load();
}
register_deactivation_hook(TRANSCY_FILE, 'transcy_deactivate_plugin');

/**
 * The code that runs when plugin uninstall
 */
function transcy_uninstall_plugin() {
    $uninstall = new Uninstall();
    $uninstall->load();
}
register_uninstall_hook(TRANSCY_FILE, 'transcy_uninstall_plugin');


/*
* Woocommerce support
*/
use Transcy\Woocommerce\Currency;
use Transcy\Base\Tracking;
function woocommerce_detect_currency( $option_name, $old_value, $option_value ){
    if( $option_name == 'woocommerce_currency' ){
        /*
        * detect changing &
        * return Tracking
        */ 
        $currency_symbol = Currency::get();
        $lang = get_bloginfo("language");
        $tracking = new Tracking();
        $tracking->trackingWoocommerce($lang,$option_value);
        
    }
}
add_action('updated_option', 'woocommerce_detect_currency', 10, 3);

if(!function_exists('wp_dump')) :
    function wp_dump(){
        if(func_num_args() === 1)
        {
            $a = func_get_args();
            echo '<pre translate=no>', var_dump( $a[0] ), '</pre><hr>';
        }
        else if(func_num_args() > 1)
            echo '<pre translate=no>', var_dump( func_get_args() ), '</pre><hr>';
        else
            throw Exception('You must provide at least one argument to this function.');
    }
endif;

add_action( 'admin_bar_menu', 'admin_bar_item', 500 );
function admin_bar_item ( WP_Admin_Bar $admin_bar ) {
	if ( ! current_user_can( 'manage_options' ) ) {
		return;
	}
	$admin_bar->add_menu( array(
		'id'    => 'menu-id',
		'parent' => null,
		'group'  => null,
		'title' => 'Menu Title', //you can use img tag with image link. it will show the image icon Instead of the title.
		'href'  => admin_url('admin.php?page=custom-page'),
		'meta' => [
			'title' => __( 'Menu Title', 'textdomain' ), //This title will show on hover
		]
	) );
}

/**
 * Add "Settings" action link to plugins table, left side
 *
 * @param array  $links  Initial list of links.
 *
 * @return array
 */
function plugin_action_links($links)
{
    // whole plugin is for admins only
    if (false === current_user_can('administrator')) {
        return $links;
    }
    $settings_link = '<a href="' . admin_url('admin.php?page=transcy-dashboard') . '">' . __( 'Settings', 'transcy' ) . '</a>';

    array_unshift($links, $settings_link);

    return $links;
} // plugin_action_links

add_filter('plugin_action_links_' . plugin_basename(TRANSCY_FILE), 'plugin_action_links');
